#
# spec file for package python-django-redis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-redis
Version:        5.3.0
Release:        1.1
Summary:        A redis cache backend for Django
License:        BSD-3-Clause
URL:            https://github.com/jazzband/django-redis
Source:         https://files.pythonhosted.org/packages/source/d/django-redis/django-redis-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module lz4 >= 0.15}
BuildRequires:  %{python_module msgpack >= 0.4.6}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest-mock >= 3.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis >= 2.10.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  psmisc
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-lz4 >= 0.15
Requires:       python-msgpack >= 0.4.6
Requires:       python-redis >= 2.10.0
BuildArch:      noarch
%python_subpackages

%description
A redis cache backend for Django.

%prep
%setup -q -n django-redis-%{version}
sed -i '/addopts/d' setup.cfg

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
/usr/sbin/redis-server --port 6379 &
export PYTHONPATH=${PWD}:${PWD}/tests
%{python_expand \
DJANGO_SETTINGS_MODULE=tests.settings.sqlite_sharding $python -m pytest -rs -v tests
DJANGO_SETTINGS_MODULE=tests.settings.sqlite_herd $python -m pytest -rs -v tests
DJANGO_SETTINGS_MODULE=tests.settings.sqlite_json $python -m pytest -rs -v tests
DJANGO_SETTINGS_MODULE=tests.settings.sqlite_msgpack $python -m pytest -rs -v tests
DJANGO_SETTINGS_MODULE=tests.settings.sqlite_zlib $python -m pytest -rs -v tests
DJANGO_SETTINGS_MODULE=tests.settings.sqlite_lz4 $python -m pytest -rs -v tests
}
killall redis-server

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/django[-_]redis*/

%changelog
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 5.3.0:
  * Add support for django 4
  * Access `django_redis.cache.DJANGO_REDIS_SCAN_ITERSIZE` and
    `django_redis.client.herd.CACHE_HERD_TIMEOUT` in runtime to
    not read Django settings in import time.
  * Skipping pickle serializer test for django >= 4.2
  * Speed up deleting multiple keys by a pattern with pipelines
    and larger itersize
  * Print full exception traceback when logging ignored
    exceptions
  * Fix mypy linting
  * Added support for python 3.11
  * Fix CI, running tox<4 to still support Python 3.6.
  * Dropped support for django 2.2 and 3.1
  * Run actions & tox against Django 4..2
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Tue Oct 11 2022 John Vandenberg <jayvdb@gmail.com>
- Drop unnecessary clean-cache.patch
- Update to v5.2.0
  * Block use with broken redis-py 4.0.0 and 4.0.1
  * Add support for django 4
- from v5.1.0
  * Add Python 3.10 to CI
  * Configured towncrier to generate the changelog.
  * Added django_redis.compressors.zstd.ZStdCompressor to provide
    pyzstd cache value compression
  * Change pickle default version to Python default instead of
    highest version
  * Add hiredis extra dependency to request redis[hiredis]
  * Add pexpireat to allow setting 'expire at' with millisecond
    precision
  * Make expire, pexpire, expireat and persist return the redis
    client value
  * Convert most unittest class tests to pytest tests
  * Update type comments to type annotations
  * Pin redis-py to 3.x until 4.x breaking changes can be addressed
  * Clarify redis primary name in sentinel documentation
  * Add documentation on configuring self signed SSL certificates
- from v5.0.0
  * supporting django 3.1 and django 3.2
  * dropped support for python 3.5
  * added support for python 3.9
  * started type hinting the codebase
  * ensure connections are closed
  * fixed ShardClient .clear() method
  * .delete() now returns boolean from django 3.1 onwards
  * disconnect connection pools on .close()
  * added support for redis sentinel
  * added .expire_at() method
  * fixed .incr() when ttl is None or when the number is larger than 64 bit
  * fixed .incr_version() when ttl is None
  * added .pttl() method to the clients to support milli-second precision
    for ttl of a key
  * added .pexpire() method to the clients to support milli-second
    precision for setting expiry of a key
* Wed May 11 2022 pgajdos@suse.com
- python-mock is not required for build
* Fri Mar 12 2021 Markéta Machová <mmachova@suse.com>
- Fix recent build failure with clean-cache.patch
* Fri Jun 12 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 4.12.1
- drop msgpack-1.patch
  * moved under jazzband.co
  * Removed support for end-of-life Django
  * Removed support for unmaintained redis-py 2.X.
  * Changed uses of deprecated smart_text() to smart_str().
  * Fixed deprecation warning with the msgpack serializer.
  * The .touch() method now uses the default timeout, to cache forever pass None.
  * Subclasses of JSONSerializer can now override the encoder_class attribute
    to change the JSON encoder. It defaults to DjangoJSONEncoder.
  * Fixed DefaultClient.set() to work with empty Pipeline.
  * The thread_local parameter is now forwarded to the Redis client.
* Fri Apr 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build with new msgpack:
  * msgpack-1.patch
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.11.0:
  * Added support for Python 3.8.
  * Added support for Django 2.2 and 3.0.
  * Changed msgpack-python soft dependency to msgpack.
  * Fixed .touch() method for sharded client.
  * Fixed prefix escaping for the sharded client.
  * Fixed .add() method to return a bool.
- Remove merged tests-fix-urls.patch
* Wed Feb 20 2019 John Vandenberg <jayvdb@gmail.com>
- Add tests-fix-urls.patch fixing failing tests, which were using
  URLs not able to be parsed correctly on Python 3 as a URL.
  See https://github.com/andymccurdy/redis-py/issues/961
* Tue Dec 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.10.0:
  * support for redis-py 3.0
* Fri Aug 31 2018 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from description.
* Tue Aug 28 2018 tchvatal@suse.com
- Initial package, needed by weblate for caching
